@@ -4,7 +4,7 @@ require DynaLoader;
 use Carp qw(croak);
 use vars qw($VERSION @EXPORT @ISA);
 
-$VERSION = '0.02'; 
+$VERSION = '0.03'; 
 
 @EXPORT = qw(sift detect_faces );
 
@@ -221,7 +221,7 @@ L<http://perlmonks.org/>.
 
 I've given one lightning talk about this module at Perl conferences:
 
-L<http://corion.net/talks/Image-CCV-lightning/Image-CCV-lightning.html|German Perl Workshop, German>
+L<German Perl Workshop, German|http://corion.net/talks/Image-CCV-lightning/Image-CCV-lightning-talk.de.html>
 
 =head1 BUG TRACKER
 
